OiRA

Help

1. Undirbúningur
3. Greining + Mat
4. Aðgerðaáætlun
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Áhættan er til staðar
5. Skýrsla
6. Staða 9%

# Commercial guarding, Leicester

Þegar búið er að greina og meta áhættur þarf að gera aðgerðaáætlun um útbætur. Best er að fjarlægja áhættur en ef það er ekki hægt þarf að grípa til annarra ráðstafanna.

Í þessu skrefi þarf m.a. að:

1. Er hægt að komast hjá áhættunni? Er hægt að fjarlægja hana? Þetta mætti t.d. gera með því að:
   - Kanna hvort þessi aðgerð eða verk er nauðsynlegt
   - Fjarlægja áhættuna eða minnka verlulega t.d. með því að nota hættuminni efni, sem gera sama gagn.
2. Grípa til annara ráðstafanna ef ekki er hægt að fjarlægja eða útiloka hættuna.
   - T.d. nota persónuhlífar.
   - Finna öruggt veklage með tiheyrandi fræðslu og þjálfun.

Þegar þetta liggur fyrir er hægt að lýsa því hvernig best er að framkvæma úrbæturnar eða þær aðgerðir sem þarf til þess að hafa stjórn á greindri áhættu. Það er mikilvægt að lýsingin sé leiðbeinandi um atriði sem geta verið flókin eða á annan hátt valdið misskilningi. Einnig er mikilvægt að fram komi hvaða þekkingu eða jafnvel réttindi þarf til að framkvæma aðgerðirnar.

Gerð aðgerðaáætlunar

Scroll to top
Back

## action-plan-landing.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More